/*
 * Copyright (c) 2003-2004 Henri Sivonen, Yrj Kari-Koskinen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package fi.iki.hsivonen.xml;
import javax.xml.parsers.SAXParserFactory;

import org.ccil.cowan.tagsoup.Parser;
import org.xml.sax.XMLReader;

import fi.iki.hsivonen.schemas.dtd.DTDCatalog;

/**
 *
 * @author hsivonen
 * @author ykk@kallio.tky.hut.fi
 */
public class SAXUtils {
    
    /**
     * Instantiates a new <code>XMLReader</code> which is configured to be 
     * non-validating. The entity resolver is set to the local DTD catalog. 
     * The entity resolver doesn't connect to the network.
     * 
     * @return a non-validating <code>XMLReader</code>
     */
    public static final XMLReader newNonvalidatingXMLReader() {
        SAXParserFactory factory = SAXParserFactory.newInstance();
        factory.setNamespaceAware(true);
        factory.setValidating(false);
        try {
            XMLReader reader = factory.newSAXParser().getXMLReader();
            reader.setEntityResolver(DTDCatalog.getInstance());
            return reader;
        } catch(Exception e) {
            throw new RuntimeException(e);
        }
    }
	
	/**
	 * Instantiates a new <code>XMLReader</code> which is configured to be 
	 * validating. The entity resolver is set to the local DTD catalog. 
	 * The entity resolver doesn't connect to the network.
	 * 
	 * @return a validating <code>XMLReader</code>
	 */
	public static final XMLReader newValidatingXMLReader() {
		SAXParserFactory factory = SAXParserFactory.newInstance();
		factory.setNamespaceAware(true);
		factory.setValidating(true);
		try {
			XMLReader reader = factory.newSAXParser().getXMLReader();
			reader.setEntityResolver(DTDCatalog.getInstance());
			return reader;
		} catch(Exception e) {
			throw new RuntimeException(e);
		}
	}

	/**
	 * Instantiates a new <code>XMLReader</code> which can parse HTML 
	 * but appears to parse XHTML. <em>Note:</em> If you are parsing 
	 * from a byte stream, you <em>must</em> set the character encoding 
	 * of the <code>InputSource</code> explicitly. Use 
	 * <code>MetadataExtractor</code> if in doubt.
	 * 
	 * @return an <code>XMLReader</code> for parsing tag soup
	 */	
	public static final XMLReader newTagSoupXMLReader() {
		return new Parser();	
	}
    
}
