/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template;
import java.io.IOException;

/**
 * An encapsulation of a typed byte buffer that can be written to a stream.
 *
 * @version $Id: ByteBufferItem.java,v 1.12 2004/08/28 16:20:07 hsivonen Exp $
 * @author  hsivonen
 */
public interface ByteBufferItem extends Item {

    /** 
     * Returns the MIME type of this item. The type may include parameters 
     * such as <code>charset</code>. The returned string must be suitable 
     * to be used as the value of the HTTP <code>Content-Type</code> header. 
     *
     * @return the content type string of this item
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public String getContentType() throws DataSourceException, IOException;

    /** 
     * Returns the number of bytes that <code>writeToOutputStream()</code> 
     * will write to an output stream or -1 if the number of bytes to be 
     * written is unknown. 
     *
     * @return the byte length of this item or -1 if unknown
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public int getContentLength() throws DataSourceException, IOException;

    /** 
     * Writes the bytes of this item to the specified 
     * <code>OutputStream</code>.
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public void writeToOutputStream(java.io.OutputStream out)
        throws DataSourceException, IOException;

}
