/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template;
import java.io.IOException;

/**
 * A wrapper for a DOM tree representing an XHTML 1.0 Strict document.
 *
 * @version $Id: DocumentItem.java,v 1.12 2004/08/28 16:20:07 hsivonen Exp $
 * @author  hsivonen
 */
public interface DocumentItem extends Item {

    /**
     * Returns the DOM representation (DOM Level 2; namespace-aware; entities 
     * expanded) of this item. The structure of the DOM tree should be that 
     * of a valid XHTML 1.0 Strict document. However, the DOM tree does not 
     * need to contain doctype nodes. Also, the namespace prefixes don't 
     * matter. The DOM builder is encouraged to discard comments and coalesce 
     * CDATA sections into text nodes.
     *
     * The <code>TemplateEngine</code> is only interested in things exposed 
     * through the SAX2 <code>ContentHandler</code>. If you use a 
     * <code>DocumentBuilderFactory</code>, the recommended options are<br>
     * <code>factory.setNamespaceAware(true); // must<br>
     * factory.setExpandEntityReferences(true); // must<br>
     * factory.setCoalescing(true); // recommended<br>
     * factory.setIgnoringComments(true); //recommended</code>
     *
     * @return the DOM representation of this item
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public org.w3c.dom.Document getDocument()
        throws DataSourceException, IOException;

}
