/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template;
import gnu.xml.pipeline.EventConsumer;

import org.xml.sax.SAXException;

/**
 *
 * @version $Id: TemplateOutputCleaner.java,v 1.9 2004/08/28 17:00:31 hsivonen Exp $
 * @author  hsivonen
 */
public class TemplateOutputCleaner extends gnu.xml.pipeline.EventFilter {

    private boolean rootSeen;

    /** Creates a new instance of TemplateOutputCleaner */
    public TemplateOutputCleaner(EventConsumer next) {
        super(next);
        this.rootSeen = false;
    }

    public void startDocument() throws SAXException {
        this.rootSeen = false;
        super.startDocument();
    }

    public void startElement(
        String namespaceURI,
        String str1,
        String str2,
        org.xml.sax.Attributes attributes)
        throws SAXException {
        if (!TemplateEngine.TEMPLATE_NS.equals(namespaceURI)) {
            this.rootSeen = true;
            super.startElement(namespaceURI, str1, str2, attributes);
        } else if (!this.rootSeen) {
            throw new SAXException("The root element was in the template namespace");
        }
    }

    public void endElement(String namespaceURI, String str1, String str2)
        throws SAXException {
        if (!TemplateEngine.TEMPLATE_NS.equals(namespaceURI)) {
            super.endElement(namespaceURI, str1, str2);
        }
    }
}
